#[repr(u8)]pub enum TicketTypeRepr {
V1MixnetEntry = 0,
V1MixnetExit = 1,
V1WireguardEntry = 2,
V1WireguardExit = 3,
}Expand description
This type is defined mostly for the purposes of having constants (like sizes) associated with given variants It’s not meant to be serialised or have any fancy traits defined on it (in this crate)
Variants
Implementations
Sourceimpl TicketTypeRepr
impl TicketTypeRepr
pub const WIREGUARD_ENTRY_TICKET_SIZE: u64
pub const WIREGUARD_EXIT_TICKET_SIZE: u64
pub const MIXNET_ENTRY_TICKET_SIZE: u64
pub const MIXNET_EXIT_TICKET_SIZE: u64
Sourcepub const fn bandwidth_value(&self) -> u64
pub const fn bandwidth_value(&self) -> u64
How much bandwidth (in bytes) one ticket can grant