pub struct CredentialSpendingData {
pub payment: Payment,
pub pay_info: PayInfo,
pub spend_date: Date,
pub epoch_id: u64,
}Fields
payment: Paymentpay_info: PayInfospend_date: Dateepoch_id: u64The (DKG) epoch id under which the credential has been issued so that the verifier could use correct verification key for validation.
Implementations
Sourceimpl CredentialSpendingData
impl CredentialSpendingData
pub fn verify( &self, verification_key: &VerificationKeyAuth, ) -> Result<(), CompactEcashError>
pub fn encoded_serial_number(&self) -> Vec<u8> ⓘ
pub fn serial_number_b58(&self) -> String
pub fn to_bytes(&self) -> Vec<u8> ⓘ
pub fn try_from_bytes(raw: &[u8]) -> Result<Self, CompactEcashError>