pub struct PayInfo {
pub pay_info_bytes: [u8; 72],
}Expand description
Represents the unique payment information associated with the payment.
The bytes representing the payment information encode the public key of the provider with whom you are spending the payment, timestamp and a unique random 32 bytes.
Fields
payinfo_bytes- An array of bytes representing the payment information.
Fields
pay_info_bytes: [u8; 72]Trait Implementations
Sourceimpl Bytable for PayInfo
impl Bytable for PayInfo
fn to_byte_vec(&self) -> Vec<u8> ⓘ
fn try_from_byte_slice(slice: &[u8]) -> Result<PayInfo, CompactEcashError>
Sourceimpl<'de> Deserialize<'de> for PayInfo
impl<'de> Deserialize<'de> for PayInfo
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<PayInfo, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<PayInfo, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<NymPayInfo> for PayInfo
impl From<NymPayInfo> for PayInfo
Sourcefn from(value: NymPayInfo) -> Self
fn from(value: NymPayInfo) -> Self
Converts to this type from the input type.
Sourceimpl From<PayInfo> for NymPayInfo
impl From<PayInfo> for NymPayInfo
Sourceimpl Serialize for PayInfo
impl Serialize for PayInfo
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for PayInfo
impl Eq for PayInfo
impl StructuralPartialEq for PayInfo