pub struct RequestInfo { /* private fields */ }Expand description
Represents information associated with a withdrawal request.
This structure holds the commitment hash, commitment opening, private attributes openings, the wallet secret (scalar), and the expiration date related to a withdrawal request.
Implementations
Sourceimpl RequestInfo
impl RequestInfo
pub fn get_joined_commitment_hash(&self) -> &G1Projective
pub fn get_joined_commitment_opening(&self) -> &Scalar
pub fn get_private_attributes_openings(&self) -> &[Scalar]
pub fn get_v(&self) -> &Scalar
pub fn get_expiration_date(&self) -> &Scalar
pub fn get_t_type(&self) -> &Scalar
Sourceimpl RequestInfo
impl RequestInfo
pub fn to_bytes(&self) -> Vec<u8> ⓘ
pub fn from_bytes(bytes: &[u8]) -> Result<RequestInfo, CompactEcashError>