WalletSignatures

Struct WalletSignatures 

pub struct WalletSignatures { /* private fields */ }
The struct represents a wallet with essential components for a payment transaction.

A Wallet includes a Pointcheval-Sanders signature (sig), a scalar value (v) representing the wallet’s secret, an optional an expiration date (expiration_date) and an u64 (‘l’) indicating the total number of spent coins.

Implementations

Source

impl WalletSignatures

pub fn with_tickets_spent(self, tickets_spent: u64) -> Wallet

pub fn new_wallet(self) -> Wallet

pub fn encoded_expiration_date(&self) -> Scalar

Source

impl WalletSignatures

pub const SERIALISED_SIZE: usize = 133

pub fn signature(&self) -> &Signature

pub fn to_bytes(&self) -> [u8; 133]

Converts the WalletSignatures to a fixed-size byte array.

The resulting byte array has a length of 168 bytes and contains serialized representations of the Signature (sig), scalar value (v), and expiration date (expiration_date) fields of the WalletSignatures struct.

Returns

A fixed-size byte array ([u8; 136]) representing the serialized form of the Wallet.

pub fn from_bytes(bytes: &[u8]) -> Result<WalletSignatures, CompactEcashError>

pub fn spend<BI, BE>( &self, params: &Parameters, verification_key: &VerificationKeyAuth, sk_user: &SecretKeyUser, pay_info: &PayInfo, current_tickets_spent: u64, spend_value: u64, valid_dates_signatures: &[BE], coin_indices_signatures: &[BI], spend_date_timestamp: u32, ) -> Result<Payment, CompactEcashError>
where BI: Borrow<Signature>, BE: Borrow<Signature>,

Performs a spending operation with the given parameters, updating the wallet and generating a payment.

Arguments
  • verification_key - The global verification key.
  • sk_user - The secret key of the user who wants to spend from their wallet.
  • pay_info - Unique information related to the payment.
  • current_tickets_spent - The total number of tickets already spent in the associated wallet.
  • spend_value - The amount to spend from the wallet.
  • valid_dates_signatures - A list of SORTED signatures on valid dates during which we can spend from the wallet.
  • coin_indices_signatures - A list of SORTED signatures on coin indices.
  • spend_date - The date on which the spending occurs, expressed as unix timestamp.
Returns

A tuple containing the generated payment and a reference to the updated wallet, or an error.