pub struct WithdrawalRequest { /* private fields */ }Expand description
Represents a withdrawal request generate by the client who wants to obtain a zk-nym credential.
This struct encapsulates the necessary components for a withdrawal request, including the joined commitment hash, the joined commitment, individual Pedersen commitments for private attributes, and a zero-knowledge proof for the withdrawal request.
Fields
joined_commitment_hash- The joined commitment hash represented as a G1Projective element.joined_commitment- The joined commitment represented as a G1Projective element.private_attributes_commitments- A vector of individual Pedersen commitments for private attributes represented as G1Projective elements.zk_proof- The zero-knowledge proof for the withdrawal request.
Derives
The struct derives Debug and PartialEq to provide debug output and basic comparison functionality.
Implementations
Sourceimpl WithdrawalRequest
impl WithdrawalRequest
pub fn get_private_attributes_commitments(&self) -> &[G1Projective]
Sourceimpl WithdrawalRequest
impl WithdrawalRequest
pub fn to_bytes(&self) -> Vec<u8> ⓘ
pub fn from_bytes(bytes: &[u8]) -> Result<WithdrawalRequest, CompactEcashError>